<?php
/**
 * Extend Media Upload
 *
 * @package    Extend Media Upload
 * @subpackage ExtendMediaUploadAdmin Main & Management screen
/*
	Copyright (c) 2018- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

$extendmediauploadadmin = new ExtendMediaUploadAdmin();

/** ==================================================
 * Management screen
 */
class ExtendMediaUploadAdmin {

	/** ==================================================
	 * Path
	 *
	 * @var $upload_dir  upload_dir.
	 */
	private $upload_dir;

	/** ==================================================
	 * Path
	 *
	 * @var $upload_path  upload_path.
	 */
	private $upload_path;

	/** ==================================================
	 * Construct
	 *
	 * @since 1.00
	 */
	public function __construct() {

		if ( ! class_exists( 'ExtendMediaUpload' ) ) {
			include_once dirname( __FILE__ ) . '/class-extendmediaupload.php';
		}
		$extendmediaupload = new ExtendMediaUpload();
		list( $this->upload_dir, $upload_url, $this->upload_path ) = $extendmediaupload->upload_dir_url_path();

		add_filter( 'plugin_action_links', array( $this, 'settings_link' ), 10, 2 );
		add_action( 'admin_menu', array( $this, 'add_pages' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'load_custom_wp_admin_style' ) );
		add_action( 'admin_notices', array( $this, 'notices' ) );

	}

	/** ==================================================
	 * Add a "Settings" link to the plugins page
	 *
	 * @param  array  $links  links array.
	 * @param  string $file   file.
	 * @return array  $links  links array.
	 * @since 1.00
	 */
	public function settings_link( $links, $file ) {
		static $this_plugin;
		if ( empty( $this_plugin ) ) {
			$this_plugin = 'extend-media-upload/extendmediaupload.php';
		}
		if ( $file == $this_plugin ) {
			$links[] = '<a href="' . admin_url( 'upload.php?page=extendmediaupload-settings' ) . '">Extend Media Upload</a>';
		}
		return $links;
	}

	/** ==================================================
	 * Settings page
	 *
	 * @since 1.00
	 */
	public function add_pages() {

		add_media_page(
			__( 'Folder & Date', 'extend-media-upload' ),
			__( 'Folder & Date', 'extend-media-upload' ),
			'upload_files',
			'extendmediaupload-settings',
			array( $this, 'settings_page' )
		);

	}

	/** ==================================================
	 * Add Css and Script
	 *
	 * @since 1.00
	 */
	public function load_custom_wp_admin_style() {
		if ( $this->is_my_plugin_screen() ) {
			wp_enqueue_script( 'jquery' );
			wp_enqueue_style( 'jquery-datetimepicker', plugin_dir_url( __DIR__ ) . 'css/jquery.datetimepicker.css', array(), '2.3.4' );
			wp_enqueue_script( 'jquery-datetimepicker', plugin_dir_url( __DIR__ ) . 'js/jquery.datetimepicker.js', null, '2.3.4' );
			wp_enqueue_script( 'jquery-extendmediaupload-datetimepicker', plugin_dir_url( __DIR__ ) . 'js/jquery.extendmediaupload.datetimepicker.js', array( 'jquery' ), '1.00', false );
		}
	}

	/** ==================================================
	 * For only admin style
	 *
	 * @since 1.00
	 */
	private function is_my_plugin_screen() {
		$screen = get_current_screen();
		if ( is_object( $screen ) && 'media' == $screen->id ) {
			return true;
		} else if ( is_object( $screen ) && 'media_page_extendmediaupload-settings' == $screen->id ) {
			return true;
		} else {
			return false;
		}
	}

	/** ==================================================
	 * Settings Menu
	 */
	public function settings_page() {

		if ( ! current_user_can( 'upload_files' ) ) {
			wp_die( esc_html__( 'You do not have sufficient permissions to access this page.' ) );
		}

		$this->options_updated();

		$scriptname = admin_url( 'upload.php?page=extendmediaupload-settings' );
		$extendmediaupload_settings = get_user_option( 'extendmediaupload', get_current_user_id() );
		include_once( ABSPATH . 'wp-admin/includes/plugin.php' );

		?>
		<div class="wrap">

		<h2>Extend Media Upload</h2>

			<details>
			<summary><strong><?php esc_html_e( 'Various links of this plugin', 'extend-media-upload' ); ?></strong></summary>
			<?php $this->credit(); ?>
			</details>

			<div style="clear: both;"></div>

			<hr>
			<div class="wrap">
				<form method="post" action="<?php echo esc_url( $scriptname ); ?>">
					<?php wp_nonce_field( 'emu_set', 'extend_media_upload_settings' ); ?>
					<details style="margin-bottom: 5px;" open>
					<summary style="cursor: pointer; padding: 10px; border: 1px solid #ddd; background: #f4f4f4; color: #000;"><strong><?php esc_html_e( 'Folder', 'extend-media-upload' ); ?></strong></summary>
						<div style="display: block;padding:5px 5px">
						<?php
						if ( 1 == get_option( 'uploads_use_yearmonth_folders' ) ) {
							$year_month_html     = '<strong>' . __( 'Organize my uploads into month- and year-based folders' ) . '</strong>';
							$year_month_set_html = '<a href="' . admin_url( 'options-media.php' ) . '" style="text-decoration: none; word-break: break-all;">' . __( 'Media Settings' ) . '</a>';
							/* translators: %1$s: message %2$s: media settings */
							echo wp_kses_post( sprintf( __( '"%1$s" is checked. This is the default setting for the WordPress Media Library. In this setting, the file is moved to month- and year-based folders. If you want to specify a folder, please uncheck %2$s.', 'extend-media-upload' ), $year_month_html, $year_month_set_html ) );
						} else {
							do_action( 'emu_dir_select_box', $extendmediaupload_settings['subdir'] );
						}
						?>
						</div>
					</details>
					<details style="margin-bottom: 5px;" open>
					<summary style="cursor: pointer; padding: 10px; border: 1px solid #ddd; background: #f4f4f4; color: #000;"><strong><?php esc_html_e( 'Date' ); ?></strong></summary>
						<div style="display: block;padding:5px 5px">
						<input type="radio" name="extendmediaupload_dateset" value="new" <?php checked( 'new', $extendmediaupload_settings['dateset'] ); ?> /><?php esc_html_e( 'Update to use of the current date/time.', 'extend-media-upload' ); ?>
						</div>
						<div style="display: block; padding:5px 5px">
						<input type="radio" name="extendmediaupload_dateset" value="exif" <?php checked( 'exif', $extendmediaupload_settings['dateset'] ); ?> /><?php esc_html_e( 'Update to use of the exif information date/time.', 'extend-media-upload' ); ?>
						</div>
						<div style="display: block; padding:5px 5px">
						<input type="radio" name="extendmediaupload_dateset" value="fixed" <?php checked( 'fixed', $extendmediaupload_settings['dateset'] ); ?> /><?php esc_html_e( 'Update to use of fixed the date/time.', 'extend-media-upload' ); ?>
						</div>
						<div style="display: block; padding:5px 40px">
						<input type="text" id="datetimepicker-extendmediaupload" name="extendmediaupload_datefixed" value="<?php echo esc_attr( $extendmediaupload_settings['datefixed'] ); ?>">
						</div>
					</details>
					<details style="margin-bottom: 5px;" open>
					<summary style="cursor: pointer; padding: 10px; border: 1px solid #ddd; background: #f4f4f4; color: #000;"><strong><?php esc_html_e( 'Categories' ); ?></strong></summary>
						<div style="display: block; padding:5px 5px">
						<?php
						if ( is_plugin_active( 'extend-media-upload-add-on-category/extendmediauploadcategory.php' ) ) {
							do_action( 'emu_addon_category_form', get_current_user_id() );
						} else {
							if ( is_dir( WP_PLUGIN_DIR . '/extend-media-upload-add-on-category' ) ) {
								?>
								<h4><?php esc_html_e( 'Installed but deactivated.', 'extend-media-upload' ); ?></h4>
								<?php
								if ( is_multisite() ) {
									$plugin_page = network_admin_url( 'plugins.php' );
								} else {
									$plugin_page = admin_url( 'plugins.php' );
								}
								?>
								<a href="<?php echo esc_url( $plugin_page ); ?>" class="page-title-action"><?php esc_html_e( 'Activate "Extend Media Upload Add On Category"', 'extend-media-upload' ); ?></a>
								<?php
							} else {
								?>
								<div style="margin: 5px; padding: 5px;">
								<?php esc_html_e( 'This Add-on When registering by "Extend Media Upload", add Category to Media Library.', 'extend-media-upload' ); ?>
								<ul style="padding: 0px 15px; list-style-type: disc">
								<li><?php esc_html_e( 'Works with next plugin.', 'extend-media-upload' ); ?> [<a style="text-decoration: none;" href="https://wordpress.org/plugins/wp-media-library-categories/" target="_blank" rel="noopener noreferrer">Media Library Categories</a>] [<a style="text-decoration: none;" href="https://wordpress.org/plugins/enhanced-media-library/" target="_blank" rel="noopener noreferrer">Enhanced Media Library</a>] [<a style="text-decoration: none;" href="https://wordpress.org/plugins/media-library-assistant/" target="_blank" rel="noopener noreferrer">Media Library Assistant</a>]</li>
								</ul>
								<a href="<?php echo esc_url( __( 'https://shop.riverforest-wp.info/extend-media-upload-add-on-category/', 'extend-media-upload' ) ); ?>" target="_blank" rel="noopener noreferrer" class="page-title-action"><?php esc_html_e( 'BUY', 'extend-media-upload' ); ?></a>
								</div>
								<?php
							}
						}
						?>
						</div>
					</details>
					<details style="margin-bottom: 5px;" open>
					<summary style="cursor: pointer; padding: 10px; border: 1px solid #ddd; background: #f4f4f4; color: #000;"><strong><?php echo esc_html( 'Exif ' . __( 'Caption' ) ); ?></strong></summary>
						<div style="display: block; padding:5px 5px">
						<?php
						if ( is_plugin_active( 'extend-media-upload-add-on-exif/extendmediauploadexif.php' ) ) {
							do_action( 'emu_addon_exif_form', get_current_user_id() );
						} else {
							if ( is_dir( WP_PLUGIN_DIR . '/extend-media-upload-add-on-exif' ) ) {
								?>
								<h4><?php esc_html_e( 'Installed but deactivated.', 'extend-media-upload' ); ?></h4>
								<?php
								if ( is_multisite() ) {
									$plugin_page = network_admin_url( 'plugins.php' );
								} else {
									$plugin_page = admin_url( 'plugins.php' );
								}
								?>
								<a href="<?php echo esc_url( $plugin_page ); ?>" class="page-title-action"><?php esc_html_e( 'Activate "Extend Media Upload Add On Exif"', 'extend-media-upload' ); ?></a>
								<?php
							} else {
								?>
								<div style="margin: 5px; padding: 5px;">
								<?php esc_html_e( 'This Add-on When registering by "Extend Media Upload", add Exif to Media Library Caption.', 'extend-media-upload' ); ?>
								<ul style="padding: 0px 15px; list-style-type: disc">
								<li><?php esc_html_e( 'Sort each Exif data to an arbitrary position and insert it into the caption as text.', 'extend-media-upload' ); ?></li>
								<li><a style="text-decoration: none;" href="https://codex.wordpress.org/Function_Reference/wp_read_image_metadata#Return%20Values" target="_blank" rel="noopener noreferrer">Exif</a></li>
								</ul>
								<a href="<?php echo esc_url( __( 'https://shop.riverforest-wp.info/extend-media-upload-add-on-exif/', 'extend-media-upload' ) ); ?>" target="_blank" rel="noopener noreferrer" class="page-title-action"><?php esc_html_e( 'BUY', 'extend-media-upload' ); ?></a>
								</div>
								<?php
							}
						}
						?>
						</div>
					</details>
					<?php submit_button( __( 'Apply' ), 'primary', 'emu_screen_options_apply', true ); ?>
				</form>
			</div>

		</div>
		<?php

	}

	/** ==================================================
	 * Credit
	 *
	 * @since 1.00
	 */
	private function credit() {

		$plugin_name    = null;
		$plugin_ver_num = null;
		$plugin_path    = plugin_dir_path( __DIR__ );
		$plugin_dir     = untrailingslashit( $plugin_path );
		$slugs          = explode( '/', $plugin_dir );
		$slug           = end( $slugs );
		$files          = scandir( $plugin_dir );
		foreach ( $files as $file ) {
			if ( '.' === $file || '..' === $file || is_dir( $plugin_path . $file ) ) {
				continue;
			} else {
				$exts = explode( '.', $file );
				$ext  = strtolower( end( $exts ) );
				if ( 'php' === $ext ) {
					$plugin_datas = get_file_data(
						$plugin_path . $file,
						array(
							'name'    => 'Plugin Name',
							'version' => 'Version',
						)
					);
					if ( array_key_exists( 'name', $plugin_datas ) && ! empty( $plugin_datas['name'] ) && array_key_exists( 'version', $plugin_datas ) && ! empty( $plugin_datas['version'] ) ) {
						$plugin_name    = $plugin_datas['name'];
						$plugin_ver_num = $plugin_datas['version'];
						break;
					}
				}
			}
		}
		$plugin_version = __( 'Version:' ) . ' ' . $plugin_ver_num;
		/* translators: FAQ Link & Slug */
		$faq       = sprintf( esc_html__( 'https://wordpress.org/plugins/%s/faq', '%s' ), $slug );
		$support   = 'https://wordpress.org/support/plugin/' . $slug;
		$review    = 'https://wordpress.org/support/view/plugin-reviews/' . $slug;
		$translate = 'https://translate.wordpress.org/projects/wp-plugins/' . $slug;
		$facebook  = 'https://www.facebook.com/katsushikawamori/';
		$twitter   = 'https://twitter.com/dodesyo312';
		$youtube   = 'https://www.youtube.com/channel/UC5zTLeyROkvZm86OgNRcb_w';
		$donate    = sprintf( esc_html__( 'https://shop.riverforest-wp.info/donate/', '%s' ), $slug );

		?>
		<span style="font-weight: bold;">
		<div>
		<?php echo esc_html( $plugin_version ); ?> | 
		<a style="text-decoration: none;" href="<?php echo esc_url( $faq ); ?>" target="_blank" rel="noopener noreferrer"><?php esc_html_e( 'FAQ' ); ?></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $support ); ?>" target="_blank" rel="noopener noreferrer"><?php esc_html_e( 'Support Forums' ); ?></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $review ); ?>" target="_blank" rel="noopener noreferrer"><?php sprintf( esc_html_e( 'Reviews', '%s' ), $slug ); ?></a>
		</div>
		<div>
		<a style="text-decoration: none;" href="<?php echo esc_url( $translate ); ?>" target="_blank" rel="noopener noreferrer">
		<?php
		/* translators: Plugin translation link */
		echo sprintf( esc_html__( 'Translations for %s' ), esc_html( $plugin_name ) );
		?>
		</a> | <a style="text-decoration: none;" href="<?php echo esc_url( $facebook ); ?>" target="_blank" rel="noopener noreferrer"><span class="dashicons dashicons-facebook"></span></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $twitter ); ?>" target="_blank" rel="noopener noreferrer"><span class="dashicons dashicons-twitter"></span></a> | <a style="text-decoration: none;" href="<?php echo esc_url( $youtube ); ?>" target="_blank" rel="noopener noreferrer"><span class="dashicons dashicons-video-alt3"></span></a>
		</div>
		</span>

		<div style="width: 250px; height: 180px; margin: 5px; padding: 5px; border: #CCC 2px solid;">
		<h3><?php sprintf( esc_html_e( 'Please make a donation if you like my work or would like to further the development of this plugin.', '%s' ), $slug ); ?></h3>
		<div style="text-align: right; margin: 5px; padding: 5px;"><span style="padding: 3px; color: #ffffff; background-color: #008000">Plugin Author</span> <span style="font-weight: bold;">Katsushi Kawamori</span></div>
		<button type="button" style="margin: 5px; padding: 5px;" onclick="window.open('<?php echo esc_url( $donate ); ?>')"><?php esc_html_e( 'Donate to this plugin &#187;' ); ?></button>
		</div>

		<?php

	}

	/** ==================================================
	 * Update wp_options table.
	 *
	 * @since 1.00
	 */
	private function options_updated() {

		$extendmediaupload_settings = get_user_option( 'extendmediaupload', get_current_user_id() );

		if ( isset( $_POST['emu_screen_options_apply'] ) && ! empty( $_POST['emu_screen_options_apply'] ) ||
				isset( $_POST['emu_exif_default'] ) && ! empty( $_POST['emu_exif_default'] )
			) {
			if ( check_admin_referer( 'emu_set', 'extend_media_upload_settings' ) ) {

				if ( ! empty( $_POST['extendmediaupload_dateset'] ) ) {
					$extendmediaupload_settings['dateset'] = sanitize_text_field( wp_unslash( $_POST['extendmediaupload_dateset'] ) );
				}
				if ( ! empty( $_POST['extendmediaupload_datefixed'] ) ) {
					$extendmediaupload_settings['datefixed'] = sanitize_text_field( wp_unslash( $_POST['extendmediaupload_datefixed'] ) );
				}

				if ( ! empty( $_POST['searchdir'] ) ) {
					$subdir = urldecode( wp_strip_all_tags( wp_unslash( $_POST['searchdir'] ) ) );
					if ( false === strpos( realpath( wp_normalize_path( ABSPATH . $this->upload_path . $subdir ) ), $this->upload_dir ) ) { /* for directory traversal */
						$subdir = '/';
					}
					$extendmediaupload_settings['subdir'] = $subdir;
				}

				update_user_option( get_current_user_id(), 'extendmediaupload', $extendmediaupload_settings );

				do_action( 'emu_addon_category_options_updated' );
				do_action( 'emu_addon_exif_options_updated' );

				echo '<div class="notice notice-success is-dismissible"><ul><li>' . esc_html( __( 'Settings' ) . ' --> ' . __( 'Changes saved.' ) ) . '</li></ul></div>';

			}
		}

	}

	/** ==================================================
	 * Notices
	 *
	 * @since 1.01
	 */
	public function notices() {

		if ( $this->is_my_plugin_screen() ) {
			if ( is_multisite() ) {
				$omlf_install_url = network_admin_url( 'plugin-install.php?tab=plugin-information&plugin=organize-media-library' );
			} else {
				$omlf_install_url = admin_url( 'plugin-install.php?tab=plugin-information&plugin=organize-media-library' );
			}
			$omlf_install_html = '<a href="' . $omlf_install_url . '" style="text-decoration: none; word-break: break-all;">Organize Media Library by Folders</a>';
			if ( ! class_exists( 'OrganizeMediaLibraryAdmin' ) ) {
				/* translators: Organize Media Library by Folders link */
				echo '<div class="notice notice-warning is-dismissible"><ul><li>' . wp_kses_post( sprintf( __( 'If you want to organize media library by folders, Please use the %1$s.', 'extend-media-upload' ), $omlf_install_html ) ) . '</li></ul></div>';
			}
		}

	}

}


